==> qtjambi-designer-debuginfo-macos-5.15.18.jar: sources/QtJambiDesigner/QDesignerWidgetBoxInterface_shell.h <==
#ifndef QDESIGNERWIDGETBOXINTERFACE_SHELL_H
#define QDESIGNERWIDGETBOXINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractwidgetbox.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractdnditem.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qaction.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetBoxInterface_shell : public QDesignerWidgetBoxInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetBoxInterface_shell(QWidget* parent0 = nullptr, Qt::WindowFlags flags1 = Qt::WindowFlags());
    ~QDesignerWidgetBoxInterface_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void addCategory(const QDesignerWidgetBoxInterface::Category& cat0) override;
    void addWidget(int cat_idx0, const QDesignerWidgetBoxInterface::Widget& wgt1) override;
    QDesignerWidgetBoxInterface::Category category(int cat_idx0) const override;
    int categoryCount() const override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void dropWidgets(const QList<QDesignerDnDItemInterface*>& item_list0, const QPoint& global_mouse_pos1) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString fileName() const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    bool load() override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void removeCategory(int cat_idx0) override;
    void removeWidget(int cat_idx0, int wgt_idx1) override;
    void resizeEvent(QResizeEvent* event0) override;
    bool save() override;
    void setFileName(const QString& file_name0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    QDesignerWidgetBoxInterface::Widget widget(int cat_idx0, int wgt_idx1) const override;
    int widgetCount(int cat_idx0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetBoxInterface_access : public QDesignerWidgetBoxInterface
{
    void __qt_addCategory_cref_QDesignerWidgetBoxInterface_Category(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cat0);
    void __qt_addWidget_int_cref_QDesignerWidgetBoxInterface_Widget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, QtJambiNativeID wgt1);
    jobject __qt_category_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0) const;
    jint __qt_categoryCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_dropWidgets_cref_QList_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject item_list0, QtJambiNativeID global_mouse_pos1);
    jstring __qt_fileName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_load(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_removeCategory_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0);
    void __qt_removeWidget_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, jint wgt_idx1);
    jboolean __qt_save(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setFileName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring file_name0);
    jobject __qt_widget_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, jint wgt_idx1) const;
    jint __qt_widgetCount_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0) const;
};

#endif // QDESIGNERWIDGETBOXINTERFACE_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.5.3.jar: sources/QtJambiDesigner/QDesignerWidgetBoxInterface_shell.h <==
#ifndef QDESIGNERWIDGETBOXINTERFACE_SHELL_H
#define QDESIGNERWIDGETBOXINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractwidgetbox.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractdnditem.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetBoxInterface_shell : public QDesignerWidgetBoxInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetBoxInterface_shell(QWidget* parent0 = nullptr, Qt::WindowFlags flags1 = Qt::WindowFlags());
    ~QDesignerWidgetBoxInterface_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void addCategory(const QDesignerWidgetBoxInterface::Category& cat0) override;
    void addWidget(int cat_idx0, const QDesignerWidgetBoxInterface::Widget& wgt1) override;
    QDesignerWidgetBoxInterface::Category category(int cat_idx0) const override;
    int categoryCount() const override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* event0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void dropWidgets(const QList<QDesignerDnDItemInterface*>& item_list0, const QPoint& global_mouse_pos1) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString fileName() const override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    bool load() override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void removeCategory(int cat_idx0) override;
    void removeWidget(int cat_idx0, int wgt_idx1) override;
    void resizeEvent(QResizeEvent* event0) override;
    bool save() override;
    void setFileName(const QString& file_name0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* event0) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    QDesignerWidgetBoxInterface::Widget widget(int cat_idx0, int wgt_idx1) const override;
    int widgetCount(int cat_idx0) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetBoxInterface_access : public QDesignerWidgetBoxInterface
{
    void __qt_addCategory_cref_QDesignerWidgetBoxInterface_Category(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cat0);
    void __qt_addWidget_int_cref_QDesignerWidgetBoxInterface_Widget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, QtJambiNativeID wgt1);
    jobject __qt_category_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0) const;
    jint __qt_categoryCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_dropWidgets_cref_QList_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject item_list0, QtJambiNativeID global_mouse_pos1);
    jstring __qt_fileName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_load(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_removeCategory_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0);
    void __qt_removeWidget_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, jint wgt_idx1);
    jboolean __qt_save(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setFileName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring file_name0);
    jobject __qt_widget_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0, jint wgt_idx1) const;
    jint __qt_widgetCount_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cat_idx0) const;
};

#endif // QDESIGNERWIDGETBOXINTERFACE_SHELL_H
